==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/standbypool/kotlin/inputs/SubnetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.standbypool.kotlin.inputs

import com.pulumi.azurenative.standbypool.inputs.SubnetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Subnet of container group
 * @property id Specifies ARM resource id of the subnet.
 */
public data class SubnetArgs(
    public val id: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.standbypool.inputs.SubnetArgs> {
    override fun toJava(): com.pulumi.azurenative.standbypool.inputs.SubnetArgs =
        com.pulumi.azurenative.standbypool.inputs.SubnetArgs.builder()
            .id(id.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SubnetArgs].
 */
@PulumiTagMarker
public class SubnetArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Specifies ARM resource id of the subnet.
     */
    @JvmName("tvibtcgustyumbtv")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Specifies ARM resource id of the subnet.
     */
    @JvmName("ynwyenkebypacwum")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): SubnetArgs = SubnetArgs(
        id = id ?: throw PulumiNullFieldException("id"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/standbypool/kotlin/inputs/SubnetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.standbypool.kotlin.inputs

import com.pulumi.azurenative.standbypool.inputs.SubnetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Subnet of container group
 * @property id Specifies ARM resource id of the subnet.
 */
public data class SubnetArgs(
    public val id: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.standbypool.inputs.SubnetArgs> {
    override fun toJava(): com.pulumi.azurenative.standbypool.inputs.SubnetArgs =
        com.pulumi.azurenative.standbypool.inputs.SubnetArgs.builder()
            .id(id.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SubnetArgs].
 */
@PulumiTagMarker
public class SubnetArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Specifies ARM resource id of the subnet.
     */
    @JvmName("duvkarckyewadgir")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Specifies ARM resource id of the subnet.
     */
    @JvmName("cottrdqtdmmhkkrr")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): SubnetArgs = SubnetArgs(
        id = id ?: throw PulumiNullFieldException("id"),
    )
}
